NullHeader

Struct NullHeader 

pub struct NullHeader { /* private fields */ }
BSD Null/Loopback header

This is the link-layer header used on BSD loopback interfaces. It consists of a single 4-byte field containing the address family in host byte order.

Wire Format

The header is 4 bytes containing the protocol family in host byte order. Since most systems are little-endian, we parse it as little-endian by default, but also check for big-endian encoding for portability.

Implementations

Source

impl NullHeader

pub const SIZE: usize = 4

Header size in bytes

pub fn family_raw_le(&self) -> u32

Get the raw protocol family value (little-endian interpretation)

pub fn family_raw_be(&self) -> u32

Get the raw protocol family value (big-endian interpretation)

pub fn address_family(&self) -> AddressFamily

Get the address family

This method tries to detect the byte order by checking if the value makes sense as a known address family. It first tries little-endian (most common), then big-endian.

pub fn protocol(&self) -> EtherProto

Get the protocol as EtherProto for compatibility with the iterator