#[repr(u16)]pub enum SllPacketType {
Host = 0,
Broadcast = 1,
Multicast = 2,
OtherHost = 3,
Outgoing = 4,
LoopbackOutgoing = 5,
FastRoute = 6,
Unknown(u16),
}Expand description
SLL packet type indicating the direction/type of the packet
Variants
Host = 0
Packet was sent to us by somebody else
Broadcast = 1
Packet was broadcast by somebody else
Multicast = 2
Packet was multicast, but not broadcast, by somebody else
OtherHost = 3
Packet was sent by somebody else to somebody else
Outgoing = 4
Packet was sent by us
LoopbackOutgoing = 5
Packet was sent by us (kernel loopback)
FastRoute = 6
Packet was fastrouted (internal use)
Unknown(u16)
Unknown packet type