pub struct Packet<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Packet<'a>
impl<'a> Packet<'a>
Sourcepub fn from_bytes(
buf: &'a [u8],
link_type: LinkType,
mode: ParseMode,
) -> Result<Self, PacketHeaderError>
pub fn from_bytes( buf: &'a [u8], link_type: LinkType, mode: ParseMode, ) -> Result<Self, PacketHeaderError>
Parse a packet from raw bytes using the specified link type and parse mode.
This method directly parses all protocol layers without using an iterator,
collecting them into a structured Packet.
Arguments
buf- The raw packet byteslink_type- The link layer type of the packetmode- Parse mode:Outermostignores tunnels,Innermostparses through them
Sourcepub fn arp(&self) -> Option<&ArpHeaderFull<'a>>
pub fn arp(&self) -> Option<&ArpHeaderFull<'a>>
Returns a reference to the ARP header, if present.
Sourcepub fn network(&self) -> Option<&NetworkLayer<'a>>
pub fn network(&self) -> Option<&NetworkLayer<'a>>
Returns a reference to the network layer header, if present.
Sourcepub fn transport(&self) -> Option<&TransportLayer<'a>>
pub fn transport(&self) -> Option<&TransportLayer<'a>>
Returns a reference to the transport layer header, if present.
Sourcepub fn tunnels(&self) -> &[NetworkTunnelLayer<'a>]
pub fn tunnels(&self) -> &[NetworkTunnelLayer<'a>]
Returns a slice of IP tunnel layer headers.