pub enum TransportLayer<'a> {
Tcp(TcpHeaderOpt<'a>),
Udp(&'a UdpHeader),
Sctp(&'a SctpHeader),
Icmp(&'a IcmpHeader),
Icmp6(&'a Icmp6Header),
}Variants
Tcp(TcpHeaderOpt<'a>)
Udp(&'a UdpHeader)
Sctp(&'a SctpHeader)
Icmp(&'a IcmpHeader)
Icmp6(&'a Icmp6Header)
Implementations
Sourceimpl TransportLayer<'_>
impl TransportLayer<'_>
Sourcepub fn ports(&self) -> (u16, u16)
pub fn ports(&self) -> (u16, u16)
Extracts the source and destination ports from the transport layer header.
For TCP, UDP, and SCTP headers, returns the actual source and destination ports. For ICMP and ICMPv6 headers, which don’t have port numbers, returns (0, 0).
Returns
A tuple containing (source_port, destination_port). For protocols without port numbers, both values will be 0.