Tracker

Struct Tracker 

pub struct Tracker<K, V: Trackable> { /* private fields */ }
Flow tracker for types that have an intrinsic timestamp (via Trackable trait)

Implementations

Source

impl<K, V> Tracker<K, V>
where K: Eq + Hash + Clone, V: Trackable,

pub fn new() -> Self

pub fn with_capacity(capacity: usize) -> Self

pub fn get_or_insert_with<F>(&mut self, key: &K, create: F) -> &mut V
where F: FnOnce() -> V,

pub fn process_and_evict<F>(&mut self, process: F) -> usize
where F: FnMut(&K, &V) -> bool,

Evict entries based on a predicate function, in lru order

pub fn front(&self) -> Option<(&K, &V)>

Get the front (oldest) entry without removing it

pub fn back(&self) -> Option<(&K, &V)>

Get the back (newest) entry without removing it

pub fn pop_front(&mut self) -> Option<(K, V)>

Remove and return the front (oldest) entry

pub fn pop_back(&mut self) -> Option<(K, V)>

Remove and return the back (newest) entry

pub fn remove(&mut self, key: &K) -> Option<V>

Remove a specific entry by key

pub fn get_timestamp(&self, key: &K) -> Option<V::Timestamp>

Get the timestamp of an entry

pub fn get(&self, key: &K) -> Option<&V>

Get a reference to the value

pub fn get_mut(&mut self, key: &K) -> Option<&mut V>

Get a mutable reference to the value

pub fn iter(&self) -> impl Iterator<Item = (&K, &V)>

Iterator over entries (from oldest to newest)

pub fn iter_mut(&mut self) -> impl Iterator<Item = (&K, &mut V)>

Mutable iterator over entries (from oldest to newest)

pub fn keys(&self) -> impl Iterator<Item = &K>

Iterator over keys (from oldest to newest)

pub fn values(&self) -> impl Iterator<Item = &V>

Iterator over values (from oldest to newest)

pub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>

Mutable iterator over values (from oldest to newest)

pub fn len(&self) -> usize

Number of entries

pub fn is_empty(&self) -> bool

Check if empty